@@ -499,6 +499,7 @@ function startdo($db, $tels, $sendid, $msg, $len, $goipid=0){
                                                 elseif($goipdb[$the][send]=="SEND" && ($comm[2]=="SENDID" || $comm[2]=="GSM_LOGOUT")){//sendid失敗
                                                         $goipdb[$the]['telrow']['error'][]=$goipdb[$the]['id'];
                                                         $findokflag=0;
+							
                                                         foreach($goipdb as $the1 => $goiptmp){
                                                                 if($goiptmp[send]=="OK" && $goiptmp[provider]==$goipsend[provider] && !in_array($goiptmp[id],$goipdb[$the]['telrow']['error']) ){
                                                                         $goipdb[$the1][send]="SEND";
@@ -535,7 +536,11 @@ function startdo($db, $tels, $sendid, $msg, $len, $goipid=0){
 							sscanf($comm[3], "errorstatus:%d",$error_no);
 							//echo "erroe_no: $error_no";
 							$goipdb[$the]['tel']['error'][]=$goipdb[$the]['id'];
-							foreach($goipdb as $the1 => $goiptmp){
+							//print_r($goipdb[$the]['tel']['error']);
+							//echo "goipsend[tel][error]:".$goipsend[tel][error];
+							//print_r($errortels);
+							if(count($goipdb[$the]['tel']['error'])<=1){ 
+							    foreach($goipdb as $the1 => $goiptmp){
 								if(!check_sms_remain_count($db,$goiptmp[id],$goiptmp[name])) continue;
 								if($goiptmp[send]=="OK" && $goiptmp[provider]==$goipnow[provider] && !in_array($goiptmp[id],$goipdb[$the]['tel']['error']) ){
 									$goipdb[$the1][send]="SEND";
@@ -549,13 +554,14 @@ function startdo($db, $tels, $sendid, $msg, $len, $goipid=0){
 									dolastsend($goipdb[$the1],$len,$msg);
 									break;
 								}
-							}                                                      
-							if(!$findokflag){
+							    }                                                      
+							    if(!$findokflag){
 								//echo "update sends set error_no='$error_no',time=now() where id=".$goipdb[$the][telid];
 								$db->query("update sends set error_no='$error_no',time=now() where id='".$goipdb[$the][telid]."'");
 								array_push($errortels[$goipnow[provider]], $goipdb[$the][tel]);
 								//$db->query("delete from sends where id=$goipnow[telid]");
 								//array_push($tels[$goipsend[provider]], $goipsend[tel]); //壓回
+							    }
 							}
 							$goipdb[$the]['send']="OK";//結束了
 							$goipdb[$the][telid]=0;
